@@ -1,18 +1,19 @@
 use GIFgraph::linespoints;
+use strict;
 
 print STDERR "Processing sample 4-2\n";
 
-@data =  read_data_from_csv("sample42.dat")
+my @data =  read_data_from_csv("sample42.dat")
 	or die "Cannot read data from sample42.dat";
 
-$my_graph = new GIFgraph::linespoints( );
+my $my_graph = new GIFgraph::linespoints( );
 
 $my_graph->set( 
 	x_label => 'X Label',
 	y_label => 'Y label',
 	title => 'A Lines and Points Graph, reading a CSV file',
 	y_max_value => 80,
-	y_tick_number => 8,
+	y_tick_number => 6,
 	y_label_skip => 2,
 	markers => [ 1, 5 ],
 );
