@@ -1,16 +1,17 @@
 use GIFgraph::lines;
+use strict;
 
 print STDERR "Processing sample 5-2\n";
 
 # The reverse is in here, because I thought the falling line was 
 # depressing, but I was too lazy to retype the data set
 
-@data = ( 
+my @data = ( 
     [ qw( Jan Feb Mar Apr May Jun Jul Aug Sep ) ],
     [ reverse(4, 3, 5, 6, 3,  1.5, -1, -3, -4)]
 );
 
-$my_graph = new GIFgraph::lines();
+my $my_graph = new GIFgraph::lines();
 
 $my_graph->set( 
 	x_label => 'Month',
@@ -23,6 +24,8 @@ $my_graph->set(
 	box_axis => 0,
 	line_width => 3,
 	zero_axis_only => 1,
+	x_label_position => 1,
+	y_label_position => 1,
 );
 
 $my_graph->plot_to_gif( "sample52.gif", \@data );
